@@ -6,6 +6,10 @@
 class SkypeClient;
 typedef QMap<QString, SkypeClient *> SkypeClientMap;
 
+// For some reason the symbian MOC doesn't like it if I don't include QObject
+// even though it is present in QtCore which is included in global.h
+#include <QObject>
+
 class SkypeClientFactory : public QObject
 {
     Q_OBJECT
